==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-spanish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hits");
define("_BROWSERS","Navegadores");
define("_OPERATINGSYS","Sistemas Operativos");
define("_UNKNOWN","Desconocido");
define("_OTHER","Otro / Desconocido");
define("_MISCSTATS","Estadsticas Varias");
define("_REGUSERS","Usuarios Registrados:");
define("_ACTIVEAUTHORS","Autores Activos:");
define("_STORIESPUBLISHED","Noticias Publicadas:");
define("_SACTIVETOPICS","Temas Activos:");
define("_COMMENTSPOSTED","Comentarios Enviados:");
define("_SSPECIALSECT","Secciones Especiales:");
define("_ARTICLESSEC","Artculos en Secciones:");
define("_LINKSINLINKS","Enlaces:");
define("_LINKSCAT","Categoras en Enlaces:");
define("_NEWSWAITING","Noticias en Espera:");
define("_NUKEVERSION","Versin PHP-Nuke:");
define("_SEARCHENGINES","Motores de Bsqueda");
define("_BOTS","Robots/Spiders");
define("_STATS","Estadsticas de Acceso");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-spanish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_HITS","Hits");
define("_BROWSERS","Navegadores");
define("_OPERATINGSYS","Sistemas Operativos");
define("_UNKNOWN","Desconocido");
define("_OTHER","Otro / Desconocido");
define("_MISCSTATS","Estadsticas Varias");
define("_REGUSERS","Usuarios Registrados:");
define("_ACTIVEAUTHORS","Autores Activos:");
define("_STORIESPUBLISHED","Noticias Publicadas:");
define("_SACTIVETOPICS","Temas Activos:");
define("_COMMENTSPOSTED","Comentarios Enviados:");
define("_SSPECIALSECT","Secciones Especiales:");
define("_ARTICLESSEC","Artculos en Secciones:");
define("_LINKSINLINKS","Enlaces:");
define("_LINKSCAT","Categoras en Enlaces:");
define("_NEWSWAITING","Noticias en Espera:");
define("_NUKEVERSION","Versin PHP-Nuke:");
define("_SEARCHENGINES","Motores de Bsqueda");
define("_BOTS","Robots/Spiders");
define("_STATS","Estadsticas de Acceso");
define("_RETURNBASICSTATS","Regresar a Estadsticas Bsicas");
define("_BACKTODETSTATS","Regresar a Estadsticas Detalladas");
define("_BACKTOMAIN","Regresar al Principal");
define("_TODAYIS","Hoy es");
define("_MOSTMONTH","Mes ms activo");
define("_MOSTDAY","Da ms activo");
define("_MOSTHOUR","Hora ms activa");
define("_YEARLYSTATS","Estadsticas por Ao");
define("_MONTLYSTATS","Estadsticas Mensuales para");
define("_SPAGESVIEWS","Impresiones de Pgina");
define("_DAILYSTATS","Estadsticas Diarias para");
define("_HOURLYSTATS","Estadsticas por Horas para");

?>
